# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/feed_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import feed_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/feed_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n9google/ads/googleads_v0/proto/services/feed_service.proto\x12 google.ads.googleads.v0.services\x1a\x32google/ads/googleads_v0/proto/resources/feed.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\'\n\x0eGetFeedRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"n\n\x12MutateFeedsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x43\n\noperations\x18\x02 \x03(\x0b\x32/.google.ads.googleads.v0.services.FeedOperation\"\xd5\x01\n\rFeedOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x39\n\x06\x63reate\x18\x01 \x01(\x0b\x32\'.google.ads.googleads.v0.resources.FeedH\x00\x12\x39\n\x06update\x18\x02 \x01(\x0b\x32\'.google.ads.googleads.v0.resources.FeedH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"Z\n\x13MutateFeedsResponse\x12\x43\n\x07results\x18\x02 \x03(\x0b\x32\x32.google.ads.googleads.v0.services.MutateFeedResult\")\n\x10MutateFeedResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd9\x02\n\x0b\x46\x65\x65\x64Service\x12\x95\x01\n\x07GetFeed\x12\x30.google.ads.googleads.v0.services.GetFeedRequest\x1a\'.google.ads.googleads.v0.resources.Feed\"/\x82\xd3\xe4\x93\x02)\x12\'/v0/{resource_name=customers/*/feeds/*}\x12\xb1\x01\n\x0bMutateFeeds\x12\x34.google.ads.googleads.v0.services.MutateFeedsRequest\x1a\x35.google.ads.googleads.v0.services.MutateFeedsResponse\"5\x82\xd3\xe4\x93\x02/\"*/v0/customers/{customer_id=*}/feeds:mutate:\x01*B\xd0\x01\n$com.google.ads.googleads.v0.servicesB\x10\x46\x65\x65\x64ServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETFEEDREQUEST = _descriptor.Descriptor(
  name='GetFeedRequest',
  full_name='google.ads.googleads.v0.services.GetFeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetFeedRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=250,
)


_MUTATEFEEDSREQUEST = _descriptor.Descriptor(
  name='MutateFeedsRequest',
  full_name='google.ads.googleads.v0.services.MutateFeedsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateFeedsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateFeedsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=362,
)


_FEEDOPERATION = _descriptor.Descriptor(
  name='FeedOperation',
  full_name='google.ads.googleads.v0.services.FeedOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.FeedOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.FeedOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.FeedOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.FeedOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.FeedOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=365,
  serialized_end=578,
)


_MUTATEFEEDSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedsResponse',
  full_name='google.ads.googleads.v0.services.MutateFeedsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateFeedsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=670,
)


_MUTATEFEEDRESULT = _descriptor.Descriptor(
  name='MutateFeedResult',
  full_name='google.ads.googleads.v0.services.MutateFeedResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateFeedResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=713,
)

_MUTATEFEEDSREQUEST.fields_by_name['operations'].message_type = _FEEDOPERATION
_FEEDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_FEEDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__pb2._FEED
_FEEDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__pb2._FEED
_FEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDOPERATION.fields_by_name['create'])
_FEEDOPERATION.fields_by_name['create'].containing_oneof = _FEEDOPERATION.oneofs_by_name['operation']
_FEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDOPERATION.fields_by_name['update'])
_FEEDOPERATION.fields_by_name['update'].containing_oneof = _FEEDOPERATION.oneofs_by_name['operation']
_FEEDOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDOPERATION.fields_by_name['remove'])
_FEEDOPERATION.fields_by_name['remove'].containing_oneof = _FEEDOPERATION.oneofs_by_name['operation']
_MUTATEFEEDSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDRESULT
DESCRIPTOR.message_types_by_name['GetFeedRequest'] = _GETFEEDREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedsRequest'] = _MUTATEFEEDSREQUEST
DESCRIPTOR.message_types_by_name['FeedOperation'] = _FEEDOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedsResponse'] = _MUTATEFEEDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedResult'] = _MUTATEFEEDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedRequest = _reflection.GeneratedProtocolMessageType('GetFeedRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedService.GetFeed][google.ads.googleads.v0.services.FeedService.GetFeed].
  
  
  Attributes:
      resource_name:
          The resource name of the feed to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetFeedRequest)
  ))
_sym_db.RegisterMessage(GetFeedRequest)

MutateFeedsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedService.MutateFeeds][google.ads.googleads.v0.services.FeedService.MutateFeeds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feeds are being modified.
      operations:
          The list of operations to perform on individual feeds.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedsRequest)

FeedOperation = _reflection.GeneratedProtocolMessageType('FeedOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an feed.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed.
      update:
          Update operation: The feed is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed feed is
          expected, in this format:
          ``customers/{customer_id}/feeds/{feed_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.FeedOperation)
  ))
_sym_db.RegisterMessage(FeedOperation)

MutateFeedsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_service_pb2'
  ,
  __doc__ = """Response message for an feed mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedsResponse)

MutateFeedResult = _reflection.GeneratedProtocolMessageType('MutateFeedResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.feed_service_pb2'
  ,
  __doc__ = """The result for the feed mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateFeedResult)
  ))
_sym_db.RegisterMessage(MutateFeedResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\020FeedServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_FEEDSERVICE = _descriptor.ServiceDescriptor(
  name='FeedService',
  full_name='google.ads.googleads.v0.services.FeedService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=716,
  serialized_end=1061,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeed',
    full_name='google.ads.googleads.v0.services.FeedService.GetFeed',
    index=0,
    containing_service=None,
    input_type=_GETFEEDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__pb2._FEED,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002)\022\'/v0/{resource_name=customers/*/feeds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeeds',
    full_name='google.ads.googleads.v0.services.FeedService.MutateFeeds',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDSREQUEST,
    output_type=_MUTATEFEEDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002/\"*/v0/customers/{customer_id=*}/feeds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDSERVICE)

DESCRIPTOR.services_by_name['FeedService'] = _FEEDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import campaign_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2
from google.ads.google_ads.v0.proto.services import campaign_group_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2


class CampaignGroupServiceStub(object):
  """Service to manage campaign groups.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignGroup = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignGroupService/GetCampaignGroup',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.GetCampaignGroupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2.CampaignGroup.FromString,
        )
    self.MutateCampaignGroups = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignGroupService/MutateCampaignGroups',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsResponse.FromString,
        )


class CampaignGroupServiceServicer(object):
  """Service to manage campaign groups.
  """

  def GetCampaignGroup(self, request, context):
    """Returns the requested campaign group in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignGroups(self, request, context):
    """Creates, updates, or removes campaign groups. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignGroupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignGroup': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignGroup,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.GetCampaignGroupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__group__pb2.CampaignGroup.SerializeToString,
      ),
      'MutateCampaignGroups': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignGroups,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__group__service__pb2.MutateCampaignGroupsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.CampaignGroupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/google_ads_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import google_ads_field_category_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__category__pb2
from google.ads.google_ads.v0.proto.enums import google_ads_field_data_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/google_ads_field.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/resources/google_ads_field.proto\x12!google.ads.googleads.v0.resources\x1a\x43google/ads/googleads_v0/proto/enums/google_ads_field_category.proto\x1a\x44google/ads/googleads_v0/proto/enums/google_ads_field_data_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x8f\x06\n\x0eGoogleAdsField\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x62\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32P.google.ads.googleads.v0.enums.GoogleAdsFieldCategoryEnum.GoogleAdsFieldCategory\x12.\n\nselectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nfilterable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08sortable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x0fselectable_with\x18\x07 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x61ttribute_resources\x18\x08 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07metrics\x18\t \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08segments\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x65num_values\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x63\n\tdata_type\x18\x0c \x01(\x0e\x32P.google.ads.googleads.v0.enums.GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType\x12.\n\x08type_url\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\x0bis_repeated\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xd8\x01\n%com.google.ads.googleads.v0.resourcesB\x13GoogleAdsFieldProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__category__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GOOGLEADSFIELD = _descriptor.Descriptor(
  name='GoogleAdsField',
  full_name='google.ads.googleads.v0.resources.GoogleAdsField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.GoogleAdsField.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v0.resources.GoogleAdsField.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category', full_name='google.ads.googleads.v0.resources.GoogleAdsField.category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectable', full_name='google.ads.googleads.v0.resources.GoogleAdsField.selectable', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filterable', full_name='google.ads.googleads.v0.resources.GoogleAdsField.filterable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sortable', full_name='google.ads.googleads.v0.resources.GoogleAdsField.sortable', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selectable_with', full_name='google.ads.googleads.v0.resources.GoogleAdsField.selectable_with', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_resources', full_name='google.ads.googleads.v0.resources.GoogleAdsField.attribute_resources', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='google.ads.googleads.v0.resources.GoogleAdsField.metrics', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='google.ads.googleads.v0.resources.GoogleAdsField.segments', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_values', full_name='google.ads.googleads.v0.resources.GoogleAdsField.enum_values', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='google.ads.googleads.v0.resources.GoogleAdsField.data_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='google.ads.googleads.v0.resources.GoogleAdsField.type_url', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_repeated', full_name='google.ads.googleads.v0.resources.GoogleAdsField.is_repeated', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=1056,
)

_GOOGLEADSFIELD.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['category'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__category__pb2._GOOGLEADSFIELDCATEGORYENUM_GOOGLEADSFIELDCATEGORY
_GOOGLEADSFIELD.fields_by_name['selectable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['filterable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['sortable'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_GOOGLEADSFIELD.fields_by_name['selectable_with'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['attribute_resources'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['metrics'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['segments'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['enum_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['data_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_google__ads__field__data__type__pb2._GOOGLEADSFIELDDATATYPEENUM_GOOGLEADSFIELDDATATYPE
_GOOGLEADSFIELD.fields_by_name['type_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GOOGLEADSFIELD.fields_by_name['is_repeated'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['GoogleAdsField'] = _GOOGLEADSFIELD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GoogleAdsField = _reflection.GeneratedProtocolMessageType('GoogleAdsField', (_message.Message,), dict(
  DESCRIPTOR = _GOOGLEADSFIELD,
  __module__ = 'google.ads.google_ads.v0.proto.resources.google_ads_field_pb2'
  ,
  __doc__ = """A field or resource (artifact) used by GoogleAdsService.
  
  
  Attributes:
      resource_name:
          The resource name of the artifact. Artifact resource names
          have the form:  ``googleAdsFields/{name}``
      name:
          The name of the artifact.
      category:
          The category of the artifact.
      selectable:
          Whether the artifact can be used in a SELECT clause in search
          queries.
      filterable:
          Whether the artifact can be used in a WHERE clause in search
          queries.
      sortable:
          Whether the artifact can be used in a ORDER BY clause in
          search queries.
      selectable_with:
          The names of all resources, segments, and metrics that are
          selectable with the described artifact.
      attribute_resources:
          The names of all resources that are selectable with the
          described artifact. Fields from these resources do not segment
          metrics when included in search queries.  This field is only
          set for artifacts whose category is RESOURCE.
      metrics:
          The names of all metrics that are selectable with the
          described artifact.  This field is only set for artifacts
          whose category is either RESOURCE or SEGMENT.
      segments:
          The names of all artifacts, whether a segment or another
          resource, that segment metrics when included in search
          queries.  This field is only set for artifacts of category
          RESOURCE, SEGMENT or METRIC.
      enum_values:
          Values the artifact can assume if it is a field of type ENUM.
          This field is only set for artifacts of category SEGMENT or
          ATTRIBUTE.
      data_type:
          This field determines the operators that can be used with the
          artifact in WHERE clauses.
      type_url:
          The URL of proto describing the artifact's data type.
      is_repeated:
          Whether the field artifact is repeated.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.GoogleAdsField)
  ))
_sym_db.RegisterMessage(GoogleAdsField)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\023GoogleAdsFieldProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A client and common configurations for the Google Ads API."""

import logging
import os
import yaml
from collections import namedtuple

import google.api_core.grpc_helpers
import google.auth.transport.requests
import google.oauth2.credentials
import google.ads.google_ads.errors
from google.ads.google_ads.v0.proto.errors import errors_pb2
import grpc


_logger = logging.getLogger(__name__)

_REQUIRED_KEYS = ('client_id', 'client_secret', 'refresh_token',
                  'developer_token')
_SERVICE_CLIENT_TEMPLATE = '%sClient'
_SERVICE_GRPC_TRANSPORT_TEMPLATE = '%sGrpcTransport'
_PROTO_TEMPLATE = '%s_pb2'
_DEFAULT_TOKEN_URI = 'https://accounts.google.com/o/oauth2/token'
_DEFAULT_VERSION = 'v0'


class GoogleAdsClient(object):
    """Google Ads client used to configure settings and fetch services."""

    @classmethod
    def _get_client_kwargs_from_yaml(cls, yaml_str):
        """Utility function used to load client kwargs from YAML string.

        Args:
            yaml_str: a str containing client configuration in YAML format.

        Returns:
            A dict containing configuration data that will be provided to the
            GoogleAdsClient initializer as keyword arguments.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        config_data = yaml.safe_load(yaml_str) or {}

        if all(required_key in config_data for required_key in _REQUIRED_KEYS):
            credentials = google.oauth2.credentials.Credentials(
                None,
                refresh_token=config_data['refresh_token'],
                client_id=config_data['client_id'],
                client_secret=config_data['client_secret'],
                token_uri=_DEFAULT_TOKEN_URI)
            credentials.refresh(google.auth.transport.requests.Request())

            login_customer_id = config_data.get('login_customer_id')
            login_customer_id = str(
                login_customer_id) if login_customer_id else None

            return {'credentials': credentials,
                    'developer_token': config_data['developer_token'],
                    'endpoint': config_data.get('endpoint'),
                    'login_customer_id': login_customer_id}
        else:
            raise ValueError('A required field in the configuration data was'
                             'not found. The required fields are: %s'
                             % str(_REQUIRED_KEYS))

    @classmethod
    def get_type(cls, name, version=_DEFAULT_VERSION):
        """Returns the specified common, enum, error, or resource type.

        Args:
            name: a str indicating the name of the type that is being retrieved;
                e.g. you may specify "CampaignOperation" to retrieve a
                CampaignOperation instance.
            version: a str indicating the version of the Google Ads API to be
                used.

        Returns:
            A Message instance representing the desired type.

        Raises:
            AttributeError: If the type for the specified name doesn't exist
                in the given version.
        """
        try:
            message_type = getattr(_get_version(version).types, name)
        except AttributeError:
            raise ValueError('Specified type "%s" does not exist in Google Ads '
                             'API %s.' % (name, version))
        return message_type()

    @classmethod
    def load_from_string(cls, yaml_str):
        """Creates a GoogleAdsClient with data stored in the YAML string.

        Args:
            yaml_str: a str containing YAML configuration data used to
                initialize a GoogleAdsClient.

        Returns:
            A GoogleAdsClient initialized with the values specified in the
            string.

        Raises:
            ValueError: If the configuration lacks a required field.
        """
        return cls(**cls._get_client_kwargs_from_yaml(yaml_str))

    @classmethod
    def load_from_storage(cls, path=None):
        """Creates a GoogleAdsClient with data stored in the specified file.

        Args:
            path: a str indicating the path to a YAML file containing
                configuration data used to initialize a GoogleAdsClient.

        Returns:
            A GoogleAdsClient initialized with the values in the specified file.

        Raises:
            FileNotFoundError: If the specified configuration file doesn't
                exist.
            IOError: If the configuration file can't be loaded.
            ValueError: If the configuration file lacks a required field.
        """
        if path is None:
            path = os.path.join(os.path.expanduser('~'), 'google-ads.yaml')

        if not os.path.isabs(path):
            path = os.path.expanduser(path)

        with open(path, 'rb') as handle:
            yaml_str = handle.read()

        return cls.load_from_string(yaml_str)

    def __init__(self, credentials, developer_token, endpoint=None,
                 login_customer_id=None):
        """Initializer for the GoogleAdsClient.

        Args:
            credentials: a google.oauth2.credentials.Credentials instance.
            developer_token: a str developer token.
            endpoint: a str specifying an optional alternative API endpoint.
            login_customer_id: a str specifying a login customer ID.
        """
        _validate_login_customer_id(login_customer_id)

        self.credentials = credentials
        self.developer_token = developer_token
        self.endpoint = endpoint
        self.login_customer_id = login_customer_id

    def get_service(self, name, version=_DEFAULT_VERSION):
        """Returns a service client instance for the specified service_name.

        Args:
            name: a str indicating the name of the service for which a
                service client is being retrieved; e.g. you may specify
                "CampaignService" to retrieve a CampaignServiceClient instance.
            version: a str indicating the version of the Google Ads API to be
                used.

        Returns:
            A service client instance associated with the given service_name.

        Raises:
            AttributeError: If the specified name doesn't exist.
        """
        version = _get_version(version)

        try:
            service_client = getattr(version, _SERVICE_CLIENT_TEMPLATE % name)
        except AttributeError:
            raise ValueError('Specified service "%s" does not exist in Google '
                             'Ads API %s.' % (name, version))

        try:
            service_transport_class = getattr(
                version, _SERVICE_GRPC_TRANSPORT_TEMPLATE % name)
        except AttributeError:
            raise ValueError('Grpc transport does not exist for the specified '
                             'service "%s".' % name)

        channel = service_transport_class.create_channel(
            address=(self.endpoint if self.endpoint
                     else service_client.SERVICE_ADDRESS),
            credentials=self.credentials)

        channel = grpc.intercept_channel(
            channel,
            MetadataInterceptor(self.developer_token, self.login_customer_id),
            ExceptionInterceptor(),
        )

        service_transport = service_transport_class(channel=channel)

        return service_client(transport=service_transport)


class ExceptionInterceptor(grpc.UnaryUnaryClientInterceptor):
    """An interceptor that wraps rpc exceptions."""

    _FAILURE_KEY = 'google.ads.googleads.v0.errors.googleadsfailure-bin'
    _REQUEST_ID_KEY = 'request-id'
    # Codes that are retried upon by google.api_core.
    _RETRY_STATUS_CODES = (
        grpc.StatusCode.INTERNAL, grpc.StatusCode.RESOURCE_EXHAUSTED)

    def _get_google_ads_failure(self, trailing_metadata):
        """Gets the Google Ads failure details if they exist.

        Args:
            trailing_metadata:

        Returns:
            A GoogleAdsFailure that describes how a GoogleAds API call failed.
            Returns None if either the trailing metadata of the request did not
            return the failure details, or if the GoogleAdsFailure fails to
            parse.
        """
        for kv in trailing_metadata:
            if kv[0] == self._FAILURE_KEY:
                try:
                    ga_failure = errors_pb2.GoogleAdsFailure()
                    ga_failure.ParseFromString(kv[1])
                    return ga_failure
                except google.protobuf.message.DecodeError:
                    return None

    def _get_request_id(self, trailing_metadata):
        """Gets the request ID for the Google Ads API request.

        Args:
            trailing_metadata:

        Returns:
            A str request ID associated with the Google Ads API request, or None
            if it doesn't exist.
        """
        for kv in trailing_metadata:
            if kv[0] == self._REQUEST_ID_KEY:
                return kv[1]  # Return the found request ID.

        return None

    def _handle_grpc_exception(self, exception):
        """Handles gRPC exceptions of type RpcError by attempting to
           convert them to a more readable GoogleAdsException. Certain types of
           exceptions are not converted; if the object's trailing metadata does
           not indicate that it is a GoogleAdsException, or if it falls under
           a certain category of status code, (INTERNAL or RESOURCE_EXHAUSTED).
           See documentation for more information about gRPC status codes:
           https://github.com/grpc/grpc/blob/master/doc/statuscodes.md

        Args:
            exception: an exception of type RpcError.

        Raises:
            GoogleAdsException: If the exception's trailing metadata
                indicates that it is a GoogleAdsException.
            RpcError: If the exception's trailing metadata is empty or is not
                indicative of a GoogleAdsException, or if the exception has a
                status code of INTERNAL or RESOURCE_EXHAUSTED.
        """
        if exception._state.code not in self._RETRY_STATUS_CODES:
            trailing_metadata = exception.trailing_metadata()
            google_ads_failure = self._get_google_ads_failure(
                trailing_metadata)

            if google_ads_failure:
                request_id = self._get_request_id(trailing_metadata)

                raise google.ads.google_ads.errors.GoogleAdsException(
                    exception, exception, google_ads_failure, request_id)
            else:
                # Raise the original exception if not a GoogleAdsFailure.
                raise exception
        else:
            # Raise the original exception if error has status code
            # INTERNAL or RESOURCE_EXHAUSTED.
            raise exception

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and wraps exceptions in the rpc response.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.

        Raises:
            GoogleAdsException: If the exception's trailing metadata
                indicates that it is a GoogleAdsException.
            RpcError: If the exception's trailing metadata is empty or is not
                indicative of a GoogleAdsException, or if the exception has a
                status code of INTERNAL or RESOURCE_EXHAUSTED.
        """
        try:
            response = continuation(client_call_details, request)
        except grpc.RpcError as ex:
            self._handle_grpc_exception(ex)

        if response.exception():
            # Any exception raised within the continuation function that is not
            # an RpcError will be set on the response object and raised here.
            raise response.exception()

        return response


class LoggingInterceptor(grpc.UnaryUnaryClientInterceptor):
    """An interceptor that logs rpc requests and responses."""

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and logs API interactions.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.
        """
        _logger.debug('Method: "%s" called with Request: "%s"'
                      % (client_call_details.method, request))

        response = continuation(client_call_details, request)

        # TODO: Handle response here.

        return response


class MetadataInterceptor(grpc.UnaryUnaryClientInterceptor):
    """An interceptor that appends custom metadata to requests."""

    def __init__(self, developer_token, login_customer_id):
        self.developer_token_meta = ('developer-token', developer_token)
        self.login_customer_id_meta = (
            ('login-customer-id', login_customer_id) if login_customer_id
            else None)

    def _update_client_call_details_metadata(
            self, client_call_details, metadata):
        client_call_details = _ClientCallDetails(
            client_call_details.method, client_call_details.timeout, metadata,
            client_call_details.credentials)

        return client_call_details

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and appends custom metadata.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.
        """
        if client_call_details.metadata is None:
            metadata = []
        else:
            metadata = list(client_call_details.metadata)

        metadata.append(self.developer_token_meta)

        if self.login_customer_id_meta:
            metadata.append(self.login_customer_id_meta)

        client_call_details = self._update_client_call_details_metadata(
            client_call_details,
            metadata)

        return continuation(client_call_details, request)


class _ClientCallDetails(
        namedtuple(
            '_ClientCallDetails',
            ('method', 'timeout', 'metadata', 'credentials')),
        grpc.ClientCallDetails):
    """An wrapper class for initializing a new ClientCallDetails instance."""
    pass


def _get_version(name):
    """Returns the given API version.

    Args:
        name: a str indicating the API version.

    Returns:
        A module associated with the given API version.
    """
    try:
        version = getattr(google.ads.google_ads, name)
    except AttributeError:
        raise ValueError('Specified Google Ads API version "%s" does not exist.'
                         % name)
    return version


def _validate_login_customer_id(login_customer_id):
    """Validates a login customer ID.

    Args:
        login_customer_id: a str from config indicating a login customer ID.

    Raises:
        ValueError: If the login customer ID is not
        an int in the range 0 - 9999999999.
    """
    if login_customer_id is not None:
        if not login_customer_id.isdigit() or len(login_customer_id) != 10:
            raise ValueError('The specified login customer ID is invalid. '
                             'It must be a ten digit number represented '
                             'as a string, i.e. "1234567890"')



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

from google.ads.google_ads.v0 import types
from google.ads.google_ads.v0.services import account_budget_proposal_service_client
from google.ads.google_ads.v0.services import account_budget_service_client
from google.ads.google_ads.v0.services import ad_group_ad_service_client
from google.ads.google_ads.v0.services import ad_group_audience_view_service_client
from google.ads.google_ads.v0.services import ad_group_bid_modifier_service_client
from google.ads.google_ads.v0.services import ad_group_criterion_service_client
from google.ads.google_ads.v0.services import ad_group_feed_service_client
from google.ads.google_ads.v0.services import ad_group_service_client
from google.ads.google_ads.v0.services import age_range_view_service_client
from google.ads.google_ads.v0.services import bidding_strategy_service_client
from google.ads.google_ads.v0.services import billing_setup_service_client
from google.ads.google_ads.v0.services import campaign_audience_view_service_client
from google.ads.google_ads.v0.services import campaign_bid_modifier_service_client
from google.ads.google_ads.v0.services import campaign_budget_service_client
from google.ads.google_ads.v0.services import campaign_criterion_service_client
from google.ads.google_ads.v0.services import campaign_feed_service_client
from google.ads.google_ads.v0.services import campaign_group_service_client
from google.ads.google_ads.v0.services import campaign_service_client
from google.ads.google_ads.v0.services import campaign_shared_set_service_client
from google.ads.google_ads.v0.services import carrier_constant_service_client
from google.ads.google_ads.v0.services import change_status_service_client
from google.ads.google_ads.v0.services import conversion_action_service_client
from google.ads.google_ads.v0.services import customer_client_link_service_client
from google.ads.google_ads.v0.services import customer_client_service_client
from google.ads.google_ads.v0.services import customer_feed_service_client
from google.ads.google_ads.v0.services import customer_manager_link_service_client
from google.ads.google_ads.v0.services import customer_service_client
from google.ads.google_ads.v0.services import display_keyword_view_service_client
from google.ads.google_ads.v0.services import enums
from google.ads.google_ads.v0.services import feed_item_service_client
from google.ads.google_ads.v0.services import feed_mapping_service_client
from google.ads.google_ads.v0.services import feed_service_client
from google.ads.google_ads.v0.services import gender_view_service_client
from google.ads.google_ads.v0.services import geo_target_constant_service_client
from google.ads.google_ads.v0.services import google_ads_field_service_client
from google.ads.google_ads.v0.services import google_ads_service_client
from google.ads.google_ads.v0.services import hotel_group_view_service_client
from google.ads.google_ads.v0.services import hotel_performance_view_service_client
from google.ads.google_ads.v0.services import keyword_plan_ad_group_service_client
from google.ads.google_ads.v0.services import keyword_plan_campaign_service_client
from google.ads.google_ads.v0.services import keyword_plan_idea_service_client
from google.ads.google_ads.v0.services import keyword_plan_keyword_service_client
from google.ads.google_ads.v0.services import keyword_plan_negative_keyword_service_client
from google.ads.google_ads.v0.services import keyword_plan_service_client
from google.ads.google_ads.v0.services import keyword_view_service_client
from google.ads.google_ads.v0.services import language_constant_service_client
from google.ads.google_ads.v0.services import managed_placement_view_service_client
from google.ads.google_ads.v0.services import media_file_service_client
from google.ads.google_ads.v0.services import parental_status_view_service_client
from google.ads.google_ads.v0.services import payments_account_service_client
from google.ads.google_ads.v0.services import product_group_view_service_client
from google.ads.google_ads.v0.services import recommendation_service_client
from google.ads.google_ads.v0.services import search_term_view_service_client
from google.ads.google_ads.v0.services import shared_criterion_service_client
from google.ads.google_ads.v0.services import shared_set_service_client
from google.ads.google_ads.v0.services import topic_constant_service_client
from google.ads.google_ads.v0.services import topic_view_service_client
from google.ads.google_ads.v0.services import user_list_service_client
from google.ads.google_ads.v0.services import user_interest_service_client
from google.ads.google_ads.v0.services import video_service_client
from google.ads.google_ads.v0.services.transports import account_budget_proposal_service_grpc_transport
from google.ads.google_ads.v0.services.transports import account_budget_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_ad_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_audience_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_bid_modifier_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_criterion_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_feed_service_grpc_transport
from google.ads.google_ads.v0.services.transports import ad_group_service_grpc_transport
from google.ads.google_ads.v0.services.transports import age_range_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import bidding_strategy_service_grpc_transport
from google.ads.google_ads.v0.services.transports import billing_setup_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_audience_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_bid_modifier_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_budget_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_criterion_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_feed_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_group_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_service_grpc_transport
from google.ads.google_ads.v0.services.transports import campaign_shared_set_service_grpc_transport
from google.ads.google_ads.v0.services.transports import carrier_constant_service_grpc_transport
from google.ads.google_ads.v0.services.transports import change_status_service_grpc_transport
from google.ads.google_ads.v0.services.transports import conversion_action_service_grpc_transport
from google.ads.google_ads.v0.services.transports import customer_client_link_service_grpc_transport
from google.ads.google_ads.v0.services.transports import customer_client_service_grpc_transport
from google.ads.google_ads.v0.services.transports import customer_feed_service_grpc_transport
from google.ads.google_ads.v0.services.transports import customer_manager_link_service_grpc_transport
from google.ads.google_ads.v0.services.transports import customer_service_grpc_transport
from google.ads.google_ads.v0.services.transports import display_keyword_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import feed_item_service_grpc_transport
from google.ads.google_ads.v0.services.transports import feed_mapping_service_grpc_transport
from google.ads.google_ads.v0.services.transports import feed_service_grpc_transport
from google.ads.google_ads.v0.services.transports import gender_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import geo_target_constant_service_grpc_transport
from google.ads.google_ads.v0.services.transports import google_ads_field_service_grpc_transport
from google.ads.google_ads.v0.services.transports import google_ads_service_grpc_transport
from google.ads.google_ads.v0.services.transports import hotel_group_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import hotel_performance_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_ad_group_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_campaign_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_idea_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_keyword_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_negative_keyword_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_plan_service_grpc_transport
from google.ads.google_ads.v0.services.transports import keyword_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import language_constant_service_grpc_transport
from google.ads.google_ads.v0.services.transports import managed_placement_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import media_file_service_grpc_transport
from google.ads.google_ads.v0.services.transports import parental_status_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import payments_account_service_grpc_transport
from google.ads.google_ads.v0.services.transports import product_group_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import recommendation_service_grpc_transport
from google.ads.google_ads.v0.services.transports import search_term_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import shared_criterion_service_grpc_transport
from google.ads.google_ads.v0.services.transports import shared_set_service_grpc_transport
from google.ads.google_ads.v0.services.transports import topic_constant_service_grpc_transport
from google.ads.google_ads.v0.services.transports import topic_view_service_grpc_transport
from google.ads.google_ads.v0.services.transports import user_list_service_grpc_transport
from google.ads.google_ads.v0.services.transports import user_interest_service_grpc_transport
from google.ads.google_ads.v0.services.transports import video_service_grpc_transport


class AccountBudgetProposalServiceClient(
        account_budget_proposal_service_client.
        AccountBudgetProposalServiceClient):
    __doc__ = account_budget_proposal_service_client.AccountBudgetProposalServiceClient.__doc__
    enums = enums


class AccountBudgetServiceClient(
        account_budget_service_client.AccountBudgetServiceClient):
    __doc__ = account_budget_service_client.AccountBudgetServiceClient.__doc__
    enums = enums


class AdGroupAdServiceClient(
        ad_group_ad_service_client.AdGroupAdServiceClient):
    __doc__ = ad_group_ad_service_client.AdGroupAdServiceClient.__doc__
    enums = enums


class AdGroupAudienceViewServiceClient(
        ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient):
    __doc__ = ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient.__doc__
    enums = enums


class AdGroupBidModifierServiceClient(
        ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient):
    __doc__ = ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient.__doc__
    enums = enums


class AdGroupCriterionServiceClient(
        ad_group_criterion_service_client.AdGroupCriterionServiceClient):
    __doc__ = ad_group_criterion_service_client.AdGroupCriterionServiceClient.__doc__
    enums = enums


class AdGroupFeedServiceClient(
        ad_group_feed_service_client.AdGroupFeedServiceClient):
    __doc__ = ad_group_feed_service_client.AdGroupFeedServiceClient.__doc__
    enums = enums


class AdGroupServiceClient(ad_group_service_client.AdGroupServiceClient):
    __doc__ = ad_group_service_client.AdGroupServiceClient.__doc__
    enums = enums


class AgeRangeViewServiceClient(
        age_range_view_service_client.AgeRangeViewServiceClient):
    __doc__ = age_range_view_service_client.AgeRangeViewServiceClient.__doc__
    enums = enums


class BiddingStrategyServiceClient(
        bidding_strategy_service_client.BiddingStrategyServiceClient):
    __doc__ = bidding_strategy_service_client.BiddingStrategyServiceClient.__doc__
    enums = enums


class BillingSetupServiceClient(
        billing_setup_service_client.BillingSetupServiceClient):
    __doc__ = billing_setup_service_client.BillingSetupServiceClient.__doc__
    enums = enums


class CampaignAudienceViewServiceClient(
        campaign_audience_view_service_client.CampaignAudienceViewServiceClient):
    __doc__ = campaign_audience_view_service_client.CampaignAudienceViewServiceClient.__doc__
    enums = enums


class CampaignBidModifierServiceClient(
        campaign_bid_modifier_service_client.CampaignBidModifierServiceClient):
    __doc__ = campaign_bid_modifier_service_client.CampaignBidModifierServiceClient.__doc__
    enums = enums


class CampaignBudgetServiceClient(
        campaign_budget_service_client.CampaignBudgetServiceClient):
    __doc__ = campaign_budget_service_client.CampaignBudgetServiceClient.__doc__
    enums = enums


class CampaignCriterionServiceClient(
        campaign_criterion_service_client.CampaignCriterionServiceClient):
    __doc__ = campaign_criterion_service_client.CampaignCriterionServiceClient.__doc__
    enums = enums


class CampaignFeedServiceClient(
        campaign_feed_service_client.CampaignFeedServiceClient):
    __doc__ = campaign_feed_service_client.CampaignFeedServiceClient.__doc__
    enums = enums


class CampaignGroupServiceClient(
        campaign_group_service_client.CampaignGroupServiceClient):
    __doc__ = campaign_group_service_client.CampaignGroupServiceClient.__doc__
    enums = enums


class CampaignServiceClient(campaign_service_client.CampaignServiceClient):
    __doc__ = campaign_service_client.CampaignServiceClient.__doc__
    enums = enums


class CampaignSharedSetServiceClient(
        campaign_shared_set_service_client.CampaignSharedSetServiceClient):
    __doc__ = campaign_shared_set_service_client.CampaignSharedSetServiceClient.__doc__
    enums = enums


class CarrierConstantServiceClient(
        carrier_constant_service_client.CarrierConstantServiceClient):
    __doc__ = carrier_constant_service_client.CarrierConstantServiceClient.__doc__
    enums = enums


class ChangeStatusServiceClient(
        change_status_service_client.ChangeStatusServiceClient):
    __doc__ = change_status_service_client.ChangeStatusServiceClient.__doc__
    enums = enums


class ConversionActionServiceClient(
        conversion_action_service_client.ConversionActionServiceClient):
    __doc__ = conversion_action_service_client.ConversionActionServiceClient.__doc__
    enums = enums


class CustomerClientLinkServiceClient(
        customer_client_link_service_client.CustomerClientLinkServiceClient):
    __doc__ = customer_client_link_service_client.CustomerClientLinkServiceClient.__doc__
    enums = enums


class CustomerClientServiceClient(
        customer_client_service_client.CustomerClientServiceClient):
    __doc__ = customer_client_service_client.CustomerClientServiceClient.__doc__
    enums = enums


class CustomerFeedServiceClient(
        customer_feed_service_client.CustomerFeedServiceClient):
    __doc__ = customer_feed_service_client.CustomerFeedServiceClient.__doc__
    enums = enums


class CustomerManagerLinkServiceClient(
        customer_manager_link_service_client.CustomerManagerLinkServiceClient):
    __doc__ = customer_manager_link_service_client.CustomerManagerLinkServiceClient.__doc__
    enums = enums


class CustomerServiceClient(customer_service_client.CustomerServiceClient):
    __doc__ = customer_service_client.CustomerServiceClient.__doc__
    enums = enums


class DisplayKeywordViewServiceClient(
        display_keyword_view_service_client.DisplayKeywordViewServiceClient):
    __doc__ = display_keyword_view_service_client.DisplayKeywordViewServiceClient.__doc__
    enums = enums


class FeedItemServiceClient(feed_item_service_client.FeedItemServiceClient):
    __doc__ = feed_item_service_client.FeedItemServiceClient.__doc__
    enums = enums


class FeedMappingServiceClient(
        feed_mapping_service_client.FeedMappingServiceClient):
    __doc__ = feed_mapping_service_client.FeedMappingServiceClient.__doc__
    enums = enums


class FeedServiceClient(feed_service_client.FeedServiceClient):
    __doc__ = feed_service_client.FeedServiceClient.__doc__
    enums = enums


class GenderViewServiceClient(
        gender_view_service_client.GenderViewServiceClient):
    __doc__ = gender_view_service_client.GenderViewServiceClient.__doc__
    enums = enums


class GeoTargetConstantServiceClient(
        geo_target_constant_service_client.GeoTargetConstantServiceClient):
    __doc__ = geo_target_constant_service_client.GeoTargetConstantServiceClient.__doc__
    enums = enums


class GoogleAdsFieldServiceClient(
        google_ads_field_service_client.GoogleAdsFieldServiceClient):
    __doc__ = google_ads_field_service_client.GoogleAdsFieldServiceClient.__doc__
    enums = enums


class GoogleAdsServiceClient(google_ads_service_client.GoogleAdsServiceClient):
    __doc__ = google_ads_service_client.GoogleAdsServiceClient.__doc__
    enums = enums


class HotelGroupViewServiceClient(
        hotel_group_view_service_client.HotelGroupViewServiceClient):
    __doc__ = hotel_group_view_service_client.HotelGroupViewServiceClient.__doc__
    enums = enums


class HotelPerformanceViewServiceClient(
        hotel_performance_view_service_client.HotelPerformanceViewServiceClient
):
    __doc__ = hotel_performance_view_service_client.HotelPerformanceViewServiceClient.__doc__
    enums = enums


class KeywordPlanAdGroupServiceClient(
        keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient):
    __doc__ = keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient.__doc__
    enums = enums


class KeywordPlanCampaignServiceClient(
        keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient):
    __doc__ = keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient.__doc__
    enums = enums


class KeywordPlanIdeaServiceClient(
        keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient):
    __doc__ = keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient.__doc__
    enums = enums


class KeywordPlanKeywordServiceClient(
        keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient):
    __doc__ = keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient.__doc__
    enums = enums


class KeywordPlanNegativeKeywordServiceClient(
        keyword_plan_negative_keyword_service_client.
        KeywordPlanNegativeKeywordServiceClient):
    __doc__ = keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient.__doc__
    enums = enums


class KeywordPlanServiceClient(
        keyword_plan_service_client.KeywordPlanServiceClient):
    __doc__ = keyword_plan_service_client.KeywordPlanServiceClient.__doc__
    enums = enums


class KeywordViewServiceClient(
        keyword_view_service_client.KeywordViewServiceClient):
    __doc__ = keyword_view_service_client.KeywordViewServiceClient.__doc__
    enums = enums


class LanguageConstantServiceClient(
        language_constant_service_client.LanguageConstantServiceClient):
    __doc__ = language_constant_service_client.LanguageConstantServiceClient.__doc__
    enums = enums


class ManagedPlacementViewServiceClient(
        managed_placement_view_service_client.ManagedPlacementViewServiceClient):
    __doc__ = managed_placement_view_service_client.ManagedPlacementViewServiceClient.__doc__
    enums = enums


class MediaFileServiceClient(media_file_service_client.MediaFileServiceClient):
    __doc__ = media_file_service_client.MediaFileServiceClient.__doc__
    enums = enums


class ParentalStatusViewServiceClient(
        parental_status_view_service_client.ParentalStatusViewServiceClient):
    __doc__ = parental_status_view_service_client.ParentalStatusViewServiceClient.__doc__
    enums = enums


class PaymentsAccountServiceClient(
        payments_account_service_client.PaymentsAccountServiceClient):
    __doc__ = payments_account_service_client.PaymentsAccountServiceClient.__doc__
    enums = enums


class ProductGroupViewServiceClient(
        product_group_view_service_client.ProductGroupViewServiceClient):
    __doc__ = product_group_view_service_client.ProductGroupViewServiceClient.__doc__
    enums = enums


class RecommendationServiceClient(
        recommendation_service_client.RecommendationServiceClient):
    __doc__ = recommendation_service_client.RecommendationServiceClient.__doc__
    enums = enums


class SearchTermViewServiceClient(
        search_term_view_service_client.SearchTermViewServiceClient):
    __doc__ = search_term_view_service_client.SearchTermViewServiceClient.__doc__
    enums = enums


class SharedCriterionServiceClient(
        shared_criterion_service_client.SharedCriterionServiceClient):
    __doc__ = shared_criterion_service_client.SharedCriterionServiceClient.__doc__
    enums = enums


class SharedSetServiceClient(shared_set_service_client.SharedSetServiceClient):
    __doc__ = shared_set_service_client.SharedSetServiceClient.__doc__
    enums = enums


class TopicConstantServiceClient(
        topic_constant_service_client.TopicConstantServiceClient):
    __doc__ = topic_constant_service_client.TopicConstantServiceClient.__doc__
    enums = enums


class TopicViewServiceClient(topic_view_service_client.TopicViewServiceClient):
    __doc__ = topic_view_service_client.TopicViewServiceClient.__doc__
    enums = enums


class UserListServiceClient(user_list_service_client.UserListServiceClient):
    __doc__ = user_list_service_client.UserListServiceClient.__doc__
    enums = enums


class UserInterestServiceClient(
        user_interest_service_client.UserInterestServiceClient):
    __doc__ = user_interest_service_client.UserInterestServiceClient.__doc__
    enums = enums


class VideoServiceClient(video_service_client.VideoServiceClient):
    __doc__ = video_service_client.VideoServiceClient.__doc__
    enums = enums


class AccountBudgetProposalServiceGrpcTransport(
      account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport):
    __doc__ = account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport.__doc__


class AccountBudgetServiceGrpcTransport(
      account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport):
    __doc__ = account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport.__doc__


class AdGroupAdServiceGrpcTransport(
      ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport):
    __doc__ = ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport.__doc__


class AdGroupAudienceViewServiceGrpcTransport(
      ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport):
    __doc__ = ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport.__doc__


class AdGroupBidModifierServiceGrpcTransport(
      ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport):
    __doc__ = ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport.__doc__


class AdGroupCriterionServiceGrpcTransport(
      ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport):
    __doc__ = ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport.__doc__


class AdGroupFeedServiceGrpcTransport(
      ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport):
    __doc__ = ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport.__doc__


class AdGroupServiceGrpcTransport(
      ad_group_service_grpc_transport.AdGroupServiceGrpcTransport):
    __doc__ = ad_group_service_grpc_transport.AdGroupServiceGrpcTransport.__doc__


class AgeRangeViewServiceGrpcTransport(
      age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport):
    __doc__ = age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport.__doc__


class BiddingStrategyServiceGrpcTransport(
      bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport):
    __doc__ = bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport.__doc__


class BillingSetupServiceGrpcTransport(
      billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport):
    __doc__ = billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport.__doc__


class CampaignAudienceViewServiceGrpcTransport(
      campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport):
    __doc__ = campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport.__doc__


class CampaignBidModifierServiceGrpcTransport(
      campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport):
    __doc__ = campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport.__doc__


class CampaignBudgetServiceGrpcTransport(
      campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport):
    __doc__ = campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport.__doc__


class CampaignCriterionServiceGrpcTransport(
      campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport):
    __doc__ = campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport.__doc__


class CampaignFeedServiceGrpcTransport(
      campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport):
    __doc__ = campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport.__doc__


class CampaignGroupServiceGrpcTransport(
      campaign_group_service_grpc_transport.CampaignGroupServiceGrpcTransport):
    __doc__ = campaign_group_service_grpc_transport.CampaignGroupServiceGrpcTransport.__doc__


class CampaignServiceGrpcTransport(
      campaign_service_grpc_transport.CampaignServiceGrpcTransport):
    __doc__ = campaign_service_grpc_transport.CampaignServiceGrpcTransport.__doc__


class CampaignSharedSetServiceGrpcTransport(
      campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport):
    __doc__ = campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport.__doc__


class CarrierConstantServiceGrpcTransport(
      carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport):
    __doc__ = carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport.__doc__


class ChangeStatusServiceGrpcTransport(
      change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport):
    __doc__ = change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport.__doc__


class ConversionActionServiceGrpcTransport(
      conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport):
    __doc__ = conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport.__doc__


class CustomerClientLinkServiceGrpcTransport(
      customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport):
    __doc__ = customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport.__doc__


class CustomerClientServiceGrpcTransport(
      customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport):
    __doc__ = customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport.__doc__


class CustomerFeedServiceGrpcTransport(
      customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport):
    __doc__ = customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport.__doc__


class CustomerManagerLinkServiceGrpcTransport(
      customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport):
    __doc__ = customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport.__doc__


class CustomerServiceGrpcTransport(
      customer_service_grpc_transport.CustomerServiceGrpcTransport):
    __doc__ = customer_service_grpc_transport.CustomerServiceGrpcTransport.__doc__


class DisplayKeywordViewServiceGrpcTransport(
      display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport):
    __doc__ = display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport.__doc__


class FeedItemServiceGrpcTransport(
      feed_item_service_grpc_transport.FeedItemServiceGrpcTransport):
    __doc__ = feed_item_service_grpc_transport.FeedItemServiceGrpcTransport.__doc__


class FeedMappingServiceGrpcTransport(
      feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport):
    __doc__ = feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport.__doc__


class FeedServiceGrpcTransport(
      feed_service_grpc_transport.FeedServiceGrpcTransport):
    __doc__ = feed_service_grpc_transport.FeedServiceGrpcTransport.__doc__


class GenderViewServiceGrpcTransport(
      gender_view_service_grpc_transport.GenderViewServiceGrpcTransport):
    __doc__ = gender_view_service_grpc_transport.GenderViewServiceGrpcTransport.__doc__


class GeoTargetConstantServiceGrpcTransport(
      geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport):
    __doc__ = geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport.__doc__


class GoogleAdsFieldServiceGrpcTransport(
      google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport):
    __doc__ = google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport.__doc__


class GoogleAdsServiceGrpcTransport(
      google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport):
    __doc__ = google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport.__doc__


class HotelGroupViewServiceGrpcTransport(
      hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport):
    __doc__ = hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport.__doc__


class HotelPerformanceViewServiceGrpcTransport(
      hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport):
    __doc__ = hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport.__doc__


class KeywordPlanAdGroupServiceGrpcTransport(
      keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport):
    __doc__ = keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport.__doc__


class KeywordPlanCampaignServiceGrpcTransport(
      keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport):
    __doc__ = keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport.__doc__


class KeywordPlanIdeaServiceGrpcTransport(
      keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport):
    __doc__ = keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport.__doc__


class KeywordPlanKeywordServiceGrpcTransport(
      keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport):
    __doc__ = keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport.__doc__


class KeywordPlanNegativeKeywordServiceGrpcTransport(
      keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport):
    __doc__ = keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport.__doc__


class KeywordPlanServiceGrpcTransport(
      keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport):
    __doc__ = keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport.__doc__


class KeywordViewServiceGrpcTransport(
      keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport):
    __doc__ = keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport.__doc__


class LanguageConstantServiceGrpcTransport(
      language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport):
    __doc__ = language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport.__doc__


class ManagedPlacementViewServiceGrpcTransport(
      managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport):
    __doc__ = managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport.__doc__


class MediaFileServiceGrpcTransport(
      media_file_service_grpc_transport.MediaFileServiceGrpcTransport):
    __doc__ = media_file_service_grpc_transport.MediaFileServiceGrpcTransport.__doc__


class ParentalStatusViewServiceGrpcTransport(
      parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport):
    __doc__ = parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport.__doc__


class PaymentsAccountServiceGrpcTransport(
      payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport):
    __doc__ = payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport.__doc__
    enums = enums


class ProductGroupViewServiceGrpcTransport(
      product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport):
    __doc__ = product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport.__doc__


class RecommendationServiceGrpcTransport(
      recommendation_service_grpc_transport.RecommendationServiceGrpcTransport):
    __doc__ = recommendation_service_grpc_transport.RecommendationServiceGrpcTransport.__doc__


class SearchTermViewServiceGrpcTransport(
      search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport):
    __doc__ = search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport.__doc__


class SharedCriterionServiceGrpcTransport(
      shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport):
    __doc__ = shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport.__doc__


class SharedSetServiceGrpcTransport(
      shared_set_service_grpc_transport.SharedSetServiceGrpcTransport):
    __doc__ = shared_set_service_grpc_transport.SharedSetServiceGrpcTransport.__doc__


class TopicConstantServiceGrpcTransport(
      topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport):
    __doc__ = topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport.__doc__


class TopicViewServiceGrpcTransport(
      topic_view_service_grpc_transport.TopicViewServiceGrpcTransport):
    __doc__ = topic_view_service_grpc_transport.TopicViewServiceGrpcTransport.__doc__


class UserInterestServiceGrpcTransport(
      user_interest_service_grpc_transport.UserInterestServiceGrpcTransport):
    __doc__ = user_interest_service_grpc_transport.UserInterestServiceGrpcTransport.__doc__


class UserListServiceGrpcTransport(
      user_list_service_grpc_transport.UserListServiceGrpcTransport):
    __doc__ = user_list_service_grpc_transport.UserListServiceGrpcTransport.__doc__
    enums = enums


class VideoServiceGrpcTransport(
      video_service_grpc_transport.VideoServiceGrpcTransport):
    __doc__ = video_service_grpc_transport.VideoServiceGrpcTransport.__doc__



__all__ = (
    'enums',
    'types',
    'AccountBudgetProposalServiceClient',
    'AccountBudgetProposalServiceGrpcTransport',
    'AccountBudgetServiceClient',
    'AccountBudgetServiceGrpcTransport',
    'AdGroupAdServiceClient',
    'AdGroupAdServiceGrpcTransport',
    'AdGroupAudienceViewServiceClient',
    'AdGroupAudienceViewServiceGrpcTransport',
    'AdGroupBidModifierServiceClient',
    'AdGroupBidModifierServiceGrpcTransport',
    'AdGroupCriterionServiceClient',
    'AdGroupCriterionServiceGrpcTransport',
    'AdGroupFeedServiceClient',
    'AdGroupFeedServiceGrpcTransport',
    'AdGroupServiceClient',
    'AdGroupServiceGrpcTransport',
    'AgeRangeViewServiceClient',
    'AgeRangeViewServiceGrpcTransport',
    'BiddingStrategyServiceClient',
    'BiddingStrategyServiceGrpcTransport',
    'BillingSetupServiceClient',
    'BillingSetupServiceGrpcTransport',
    'CampaignAudienceViewServiceClient',
    'CampaignAudienceViewServiceGrpcTransport',
    'CampaignBidModifierServiceClient',
    'CampaignBidModifierServiceGrpcTransport',
    'CampaignBudgetServiceClient',
    'CampaignBudgetServiceGrpcTransport',
    'CampaignCriterionServiceClient',
    'CampaignCriterionServiceGrpcTransport',
    'CampaignFeedServiceClient',
    'CampaignFeedServiceGrpcTransport',
    'CampaignGroupServiceClient',
    'CampaignGroupServiceGrpcTransport',
    'CampaignServiceClient',
    'CampaignServiceGrpcTransport',
    'CampaignSharedSetServiceClient',
    'CampaignSharedSetServiceGrpcTransport',
    'CarrierConstantServiceClient',
    'CarrierConstantServiceGrpcTransport',
    'ChangeStatusServiceClient',
    'ChangeStatusServiceGrpcTransport',
    'ConversionActionServiceClient',
    'ConversionActionServiceGrpcTransport',
    'CustomerClientLinkServiceClient',
    'CustomerClientLinkServiceGrpcTransport',
    'CustomerClientServiceClient',
    'CustomerClientServiceGrpcTransport',
    'CustomerFeedServiceClient',
    'CustomerFeedServiceGrpcTransport',
    'CustomerManagerLinkServiceClient',
    'CustomerManagerLinkServiceGrpcTransport',
    'CustomerServiceClient',
    'CustomerServiceGrpcTransport',
    'DisplayKeywordViewServiceClient',
    'DisplayKeywordViewServiceGrpcTransport',
    'FeedItemServiceClient',
    'FeedItemServiceGrpcTransport',
    'FeedMappingServiceClient',
    'FeedMappingServiceGrpcTransport',
    'FeedServiceClient',
    'FeedServiceGrpcTransport',
    'GenderViewServiceClient',
    'GenderViewServiceGrpcTransport',
    'GeoTargetConstantServiceClient',
    'GeoTargetConstantServiceGrpcTransport',
    'GoogleAdsFieldServiceClient',
    'GoogleAdsFieldServiceGrpcTransport',
    'GoogleAdsServiceClient',
    'GoogleAdsServiceGrpcTransport',
    'HotelGroupViewServiceClient',
    'HotelGroupViewServiceGrpcTransport',
    'HotelPerformanceViewServiceClient',
    'HotelPerformanceViewServiceGrpcTransport',
    'KeywordPlanAdGroupServiceClient',
    'KeywordPlanAdGroupServiceGrpcTransport',
    'KeywordPlanCampaignServiceClient',
    'KeywordPlanCampaignServiceGrpcTransport',
    'KeywordPlanIdeaServiceClient',
    'KeywordPlanIdeaServiceGrpcTransport',
    'KeywordPlanKeywordServiceClient',
    'KeywordPlanKeywordServiceGrpcTransport',
    'KeywordPlanNegativeKeywordServiceClient',
    'KeywordPlanNegativeKeywordServiceGrpcTransport',
    'KeywordPlanServiceClient',
    'KeywordPlanServiceGrpcTransport',
    'KeywordViewServiceClient',
    'KeywordViewServiceGrpcTransport',
    'LanguageConstantServiceClient',
    'LanguageConstantServiceClientGrpcTransport',
    'ManagedPlacementViewServiceClient',
    'ManagedPlacementViewServiceGrpcTransport',
    'MediaFileServiceClient',
    'MediaFileServiceGrpcTransport',
    'ParentalStatusViewServiceClient',
    'ParentalStatusViewServiceGrpcTransport',
    'PaymentsAccountServiceClient',
    'PaymentsAccountServiceClientGrpcTransport',
    'ProductGroupViewServiceClient',
    'ProductGroupViewServiceGrpcTransport',
    'RecommendationServiceClient',
    'RecommendationServiceGrpcTransport',
    'SearchTermViewServiceClient',
    'SearchTermViewServiceGrpcTransport',
    'SharedCriterionServiceClient',
    'SharedCriterionServiceGrpcTransport',
    'SharedSetServiceClient',
    'SharedSetServiceGrpcTransport',
    'TopicConstantServiceClient',
    'TopicConstantServiceGrpcTransport',
    'TopicViewServiceClient',
    'TopicViewServiceGrpcTransport',
    'UserInterestServiceClient',
    'UserInterestServiceGrpcTransport',
    'UserListServiceClient',
    'UserListServiceClientGrpcTransport',
    'VideoServiceClient',
    'VideoServiceGrpcTransport',
)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import feed_mapping_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2
from google.ads.google_ads.v0.proto.services import feed_mapping_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2


class FeedMappingServiceStub(object):
  """Service to manage feed mappings.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetFeedMapping = channel.unary_unary(
        '/google.ads.googleads.v0.services.FeedMappingService/GetFeedMapping',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.GetFeedMappingRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2.FeedMapping.FromString,
        )
    self.MutateFeedMappings = channel.unary_unary(
        '/google.ads.googleads.v0.services.FeedMappingService/MutateFeedMappings',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.MutateFeedMappingsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.MutateFeedMappingsResponse.FromString,
        )


class FeedMappingServiceServicer(object):
  """Service to manage feed mappings.
  """

  def GetFeedMapping(self, request, context):
    """Returns the requested feed mapping in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateFeedMappings(self, request, context):
    """Creates or removes feed mappings. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FeedMappingServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetFeedMapping': grpc.unary_unary_rpc_method_handler(
          servicer.GetFeedMapping,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.GetFeedMappingRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_feed__mapping__pb2.FeedMapping.SerializeToString,
      ),
      'MutateFeedMappings': grpc.unary_unary_rpc_method_handler(
          servicer.MutateFeedMappings,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.MutateFeedMappingsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_feed__mapping__service__pb2.MutateFeedMappingsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.FeedMappingService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/call_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/call_placeholder_field.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n@google/ads/googleads_v0/proto/enums/call_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xba\x01\n\x18\x43\x61llPlaceholderFieldEnum\"\x9d\x01\n\x14\x43\x61llPlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x10\n\x0cPHONE_NUMBER\x10\x02\x12\x10\n\x0c\x43OUNTRY_CODE\x10\x03\x12\x0b\n\x07TRACKED\x10\x04\x12\x16\n\x12\x43ONVERSION_TYPE_ID\x10\x05\x12\x1e\n\x1a\x43ONVERSION_REPORTING_STATE\x10\x06\x42\xca\x01\n!com.google.ads.googleads.v0.enumsB\x19\x43\x61llPlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='CallPlaceholderField',
  full_name='google.ads.googleads.v0.enums.CallPlaceholderFieldEnum.CallPlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PHONE_NUMBER', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COUNTRY_CODE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_TYPE_ID', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_REPORTING_STATE', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=129,
  serialized_end=286,
)
_sym_db.RegisterEnumDescriptor(_CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD)


_CALLPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='CallPlaceholderFieldEnum',
  full_name='google.ads.googleads.v0.enums.CallPlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=286,
)

_CALLPLACEHOLDERFIELDENUM_CALLPLACEHOLDERFIELD.containing_type = _CALLPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['CallPlaceholderFieldEnum'] = _CALLPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CallPlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('CallPlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _CALLPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.call_placeholder_field_pb2'
  ,
  __doc__ = """Values for Call placeholder fields.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.CallPlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(CallPlaceholderFieldEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\031CallPlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import account_budget_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_account__budget__pb2
from google.ads.google_ads.v0.proto.services import account_budget_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_account__budget__service__pb2


class AccountBudgetServiceStub(object):
  """A service for fetching an account-level budget.

  Account-level budgets are mutated by creating proposal resources.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAccountBudget = channel.unary_unary(
        '/google.ads.googleads.v0.services.AccountBudgetService/GetAccountBudget',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_account__budget__service__pb2.GetAccountBudgetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_account__budget__pb2.AccountBudget.FromString,
        )


class AccountBudgetServiceServicer(object):
  """A service for fetching an account-level budget.

  Account-level budgets are mutated by creating proposal resources.
  """

  def GetAccountBudget(self, request, context):
    """Returns an account-level budget in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AccountBudgetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAccountBudget': grpc.unary_unary_rpc_method_handler(
          servicer.GetAccountBudget,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_account__budget__service__pb2.GetAccountBudgetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_account__budget__pb2.AccountBudget.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.AccountBudgetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/criterion_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/criterion_type.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n8google/ads/googleads_v0/proto/enums/criterion_type.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\x92\x03\n\x11\x43riterionTypeEnum\"\xfc\x02\n\rCriterionType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07KEYWORD\x10\x02\x12\r\n\tPLACEMENT\x10\x03\x12\n\n\x06\x44\x45VICE\x10\x06\x12\x0c\n\x08LOCATION\x10\x07\x12\x11\n\rLISTING_GROUP\x10\x08\x12\x0f\n\x0b\x41\x44_SCHEDULE\x10\t\x12\r\n\tAGE_RANGE\x10\n\x12\n\n\x06GENDER\x10\x0b\x12\x10\n\x0cINCOME_RANGE\x10\x0c\x12\x13\n\x0fPARENTAL_STATUS\x10\r\x12\x11\n\rYOUTUBE_VIDEO\x10\x0e\x12\x13\n\x0fYOUTUBE_CHANNEL\x10\x0f\x12\r\n\tUSER_LIST\x10\x10\x12\r\n\tPROXIMITY\x10\x11\x12\t\n\x05TOPIC\x10\x12\x12\x11\n\rLISTING_SCOPE\x10\x13\x12\x0c\n\x08LANGUAGE\x10\x14\x12\x0c\n\x08IP_BLOCK\x10\x15\x12\x11\n\rCONTENT_LABEL\x10\x16\x12\x0b\n\x07\x43\x41RRIER\x10\x17\x12\x11\n\rUSER_INTEREST\x10\x18\x42\xc3\x01\n!com.google.ads.googleads.v0.enumsB\x12\x43riterionTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_CRITERIONTYPEENUM_CRITERIONTYPE = _descriptor.EnumDescriptor(
  name='CriterionType',
  full_name='google.ads.googleads.v0.enums.CriterionTypeEnum.CriterionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE', index=4, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION', index=5, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_GROUP', index=6, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AD_SCHEDULE', index=7, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGE_RANGE', index=8, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GENDER', index=9, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE', index=10, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PARENTAL_STATUS', index=11, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_VIDEO', index=12, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE_CHANNEL', index=13, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_LIST', index=14, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROXIMITY', index=15, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOPIC', index=16, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_SCOPE', index=17, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LANGUAGE', index=18, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IP_BLOCK', index=19, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTENT_LABEL', index=20, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CARRIER', index=21, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='USER_INTEREST', index=22, number=24,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=114,
  serialized_end=494,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONTYPEENUM_CRITERIONTYPE)


_CRITERIONTYPEENUM = _descriptor.Descriptor(
  name='CriterionTypeEnum',
  full_name='google.ads.googleads.v0.enums.CriterionTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONTYPEENUM_CRITERIONTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=494,
)

_CRITERIONTYPEENUM_CRITERIONTYPE.containing_type = _CRITERIONTYPEENUM
DESCRIPTOR.message_types_by_name['CriterionTypeEnum'] = _CRITERIONTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionTypeEnum = _reflection.GeneratedProtocolMessageType('CriterionTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONTYPEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.criterion_type_pb2'
  ,
  __doc__ = """The possible types of a criterion.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.CriterionTypeEnum)
  ))
_sym_db.RegisterMessage(CriterionTypeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\022CriterionTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/search_term_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import search_term_targeting_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_search__term__targeting__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/search_term_view.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/resources/search_term_view.proto\x12!google.ads.googleads.v0.resources\x1a\x46google/ads/googleads_v0/proto/enums/search_term_targeting_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf2\x01\n\x0eSearchTermView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x31\n\x0bsearch_term\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x61\x64_group\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x66\n\x06status\x18\x04 \x01(\x0e\x32V.google.ads.googleads.v0.enums.SearchTermTargetingStatusEnum.SearchTermTargetingStatusB\xd8\x01\n%com.google.ads.googleads.v0.resourcesB\x13SearchTermViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_search__term__targeting__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_SEARCHTERMVIEW = _descriptor.Descriptor(
  name='SearchTermView',
  full_name='google.ads.googleads.v0.resources.SearchTermView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.SearchTermView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term', full_name='google.ads.googleads.v0.resources.SearchTermView.search_term', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v0.resources.SearchTermView.ad_group', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v0.resources.SearchTermView.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=448,
)

_SEARCHTERMVIEW.fields_by_name['search_term'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEARCHTERMVIEW.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SEARCHTERMVIEW.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_search__term__targeting__status__pb2._SEARCHTERMTARGETINGSTATUSENUM_SEARCHTERMTARGETINGSTATUS
DESCRIPTOR.message_types_by_name['SearchTermView'] = _SEARCHTERMVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchTermView = _reflection.GeneratedProtocolMessageType('SearchTermView', (_message.Message,), dict(
  DESCRIPTOR = _SEARCHTERMVIEW,
  __module__ = 'google.ads.google_ads.v0.proto.resources.search_term_view_pb2'
  ,
  __doc__ = """A search term view with metrics aggregated by search term at the ad
  group level.
  
  
  Attributes:
      resource_name:
          The resource name of the search term view. Search term view
          resource names have the form:  ``customers/{customer_id}/searc
          hTermViews/{campaign_id}_{ad_group_id}_ {URL-base64 search
          term}``
      search_term:
          The search term.
      ad_group:
          The ad group the search term served in.
      status:
          Indicates whether the search term is currently one of your
          targeted or excluded keywords.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.SearchTermView)
  ))
_sym_db.RegisterMessage(SearchTermView)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\023SearchTermViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/feed_item_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/feed_item_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n:google/ads/googleads_v0/proto/errors/feed_item_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\x87\x03\n\x11\x46\x65\x65\x64ItemErrorEnum\"\xf1\x02\n\rFeedItemError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12.\n*CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING\x10\x02\x12\'\n#CANNOT_OPERATE_ON_REMOVED_FEED_ITEM\x10\x03\x12*\n&DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE\x10\x04\x12\x1c\n\x18KEY_ATTRIBUTES_NOT_FOUND\x10\x05\x12\x0f\n\x0bINVALID_URL\x10\x06\x12\x1a\n\x16MISSING_KEY_ATTRIBUTES\x10\x07\x12\x1d\n\x19KEY_ATTRIBUTES_NOT_UNIQUE\x10\x08\x12%\n!CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE\x10\t\x12,\n(SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE\x10\nB\xc8\x01\n\"com.google.ads.googleads.v0.errorsB\x12\x46\x65\x65\x64ItemErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_FEEDITEMERRORENUM_FEEDITEMERROR = _descriptor.EnumDescriptor(
  name='FeedItemError',
  full_name='google.ads.googleads.v0.errors.FeedItemErrorEnum.FeedItemError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CONVERT_ATTRIBUTE_VALUE_FROM_STRING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_OPERATE_ON_REMOVED_FEED_ITEM', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_ATTRIBUTES_NOT_FOUND', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_URL', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_KEY_ATTRIBUTES', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY_ATTRIBUTES_NOT_UNIQUE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_KEY_ATTRIBUTE_VALUE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIZE_TOO_LARGE_FOR_MULTI_VALUE_ATTRIBUTE', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=117,
  serialized_end=486,
)
_sym_db.RegisterEnumDescriptor(_FEEDITEMERRORENUM_FEEDITEMERROR)


_FEEDITEMERRORENUM = _descriptor.Descriptor(
  name='FeedItemErrorEnum',
  full_name='google.ads.googleads.v0.errors.FeedItemErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDITEMERRORENUM_FEEDITEMERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=486,
)

_FEEDITEMERRORENUM_FEEDITEMERROR.containing_type = _FEEDITEMERRORENUM
DESCRIPTOR.message_types_by_name['FeedItemErrorEnum'] = _FEEDITEMERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItemErrorEnum = _reflection.GeneratedProtocolMessageType('FeedItemErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.feed_item_error_pb2'
  ,
  __doc__ = """Container for enum describing possible feed item errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.FeedItemErrorEnum)
  ))
_sym_db.RegisterMessage(FeedItemErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\022FeedItemErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/income_range_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/income_range_type.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n;google/ads/googleads_v0/proto/enums/income_range_type.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\x83\x02\n\x13IncomeRangeTypeEnum\"\xeb\x01\n\x0fIncomeRangeType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x17\n\x11INCOME_RANGE_0_50\x10\xb1\x90\x1f\x12\x18\n\x12INCOME_RANGE_50_60\x10\xb2\x90\x1f\x12\x18\n\x12INCOME_RANGE_60_70\x10\xb3\x90\x1f\x12\x18\n\x12INCOME_RANGE_70_80\x10\xb4\x90\x1f\x12\x18\n\x12INCOME_RANGE_80_90\x10\xb5\x90\x1f\x12\x18\n\x12INCOME_RANGE_90_UP\x10\xb6\x90\x1f\x12\x1f\n\x19INCOME_RANGE_UNDETERMINED\x10\xb0\x90\x1f\x42\xc5\x01\n!com.google.ads.googleads.v0.enumsB\x14IncomeRangeTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_INCOMERANGETYPEENUM_INCOMERANGETYPE = _descriptor.EnumDescriptor(
  name='IncomeRangeType',
  full_name='google.ads.googleads.v0.enums.IncomeRangeTypeEnum.IncomeRangeType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_0_50', index=2, number=510001,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_50_60', index=3, number=510002,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_60_70', index=4, number=510003,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_70_80', index=5, number=510004,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_80_90', index=6, number=510005,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_90_UP', index=7, number=510006,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INCOME_RANGE_UNDETERMINED', index=8, number=510000,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=119,
  serialized_end=354,
)
_sym_db.RegisterEnumDescriptor(_INCOMERANGETYPEENUM_INCOMERANGETYPE)


_INCOMERANGETYPEENUM = _descriptor.Descriptor(
  name='IncomeRangeTypeEnum',
  full_name='google.ads.googleads.v0.enums.IncomeRangeTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INCOMERANGETYPEENUM_INCOMERANGETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=354,
)

_INCOMERANGETYPEENUM_INCOMERANGETYPE.containing_type = _INCOMERANGETYPEENUM
DESCRIPTOR.message_types_by_name['IncomeRangeTypeEnum'] = _INCOMERANGETYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IncomeRangeTypeEnum = _reflection.GeneratedProtocolMessageType('IncomeRangeTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _INCOMERANGETYPEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.income_range_type_pb2'
  ,
  __doc__ = """Container for enum describing the type of demographic income ranges.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.IncomeRangeTypeEnum)
  ))
_sym_db.RegisterMessage(IncomeRangeTypeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\024IncomeRangeTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)
